@@ -18,6 +18,9 @@
 # include <inttypes.h>
 #endif
 
+# pragma clang diagnostic push
+# pragma clang diagnostic ignored "-Wbad-function-cast"
+
 /* a double has a longer mantissa than an unsigned int, */
 /* but the accuracy may be less. */
 #if _siz_long_double > 8
@@ -75,7 +78,6 @@
 # pragma clang diagnostic pop
 # pragma gcc diagnostic pop
   typedef mpz_t dinum_t;
-  typedef mpq_t didbl_t;
 #elif _use_math == DI_TOMMATH
 # define MP_WUR
 # if _hdr_tommath
@@ -85,10 +87,8 @@
 #  include <libtommath/tommath.h>
 # endif
   typedef mp_int dinum_t;
-  typedef mp_int didbl_t;
 # else /* DI_INTERNAL */
   typedef di_unum_t dinum_t;
-  typedef double didbl_t;
 #endif
 
 # if defined (__cplusplus) || defined (c_plusplus)
@@ -342,6 +342,7 @@ dinum_mul_u (dinum_t *r, di_ui_t val)
   *r *= (dinum_t) val;
 #endif
 }
+
 static inline void
 dinum_mul_uu (dinum_t *r, di_ui_t vala, di_ui_t valb)
 {
@@ -488,6 +489,8 @@ dinum_perc (dinum_t *r, dinum_t *val)
   return dval;
 }
 
+# pragma clang diagnostic pop
+
 # if defined (__cplusplus) || defined (c_plusplus)
 }
 # endif
