@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #
 # Copyright 2006-2018 Brad Lanam Walnut Creek, CA USA
-# Copyright 2020-2024 Brad Lanam Pleasant Hill CA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 
 # HP-UX doesn't have these installed.
@@ -18,19 +18,12 @@ mkdir $MKC_FILES, 0777;
 
 my $LOG = "../../${MKC_FILES}/mkconfig.log";
 my $_MKCONFIG_TMP = "${MKC_FILES}/_tmp_mkconfig";
-my $OPTIONFILE = "../../options.dat";
-my $VARSFILE = "../../${MKC_FILES}/mkc_none_c.vars";
+my $VARSFILE = "../../${MKC_FILES}/mkc_none.vars";
 my $CACHEFILE = "../../${MKC_FILES}/mkconfig.cache";
 my $REQLIB = "../../${MKC_FILES}/mkconfig.reqlibs";
 my $_MKCONFIG_DIR = "invalid";
 
 my $precc = <<'_HERE_';
-#if defined(__STDC__) || defined(__cplusplus) || defined(c_plusplus)
-# define _(x) x
-#else
-# define _(x) ()
-# define void char
-#endif
 #if defined(__cplusplus) || defined (c_plusplus)
 # define CPP_EXTERNS_BEG extern "C" {
 # define CPP_EXTERNS_END }
@@ -51,8 +44,6 @@ my $postcc = <<'_HERE_';
 #define __restrict
 _HERE_
 
-my $optionsloaded = 0;
-my %optionshash;
 my $iflevels = '';
 
 my $awkcmd = 'awk';
@@ -141,12 +132,12 @@ savecache
     open (MKCC, ">$CACHEFILE");
     foreach my $val (@{$r_clist->{'clist'}})
     {
-      if ($val =~ /^lib__lib_/o) {
+      if ($val =~ /^lnk__lib_/o) {
         $tval = $val;
-        $tval =~ s/^lib_//o;
-        print MKCC "mkc_c_lib_${tval}='" . $r_config->{$val} . "'\n";
+        $tval =~ s/^lnk_//o;
+        print MKCC "mkc_lnk__lib_${tval}='" . $r_config->{$val} . "'\n";
       } else {
-        print MKCC "mkc_c_${val}='" . $r_config->{$val} . "'\n";
+        print MKCC "mkc_${val}='" . $r_config->{$val} . "'\n";
       }
     }
     close (MKCC);
@@ -186,24 +177,6 @@ checkcache
   return $rc;
 }
 
-sub
-loadoptions
-{
-  if ($optionsloaded == 0 && open (OPTS, "<$OPTIONFILE")) {
-    while (my $o = <OPTS>) {
-      chomp $o;
-      if ($o =~ /^$/o || $o =~ /^#/o) {
-        next;
-      }
-      my ($onm, $val) = split (/=/, $o);
-      printf LOGFH "## load: $onm = $val\n";
-      $optionshash{$onm} = $val;
-    }
-    $optionsloaded = 1;
-    close (OPTS);
-  }
-}
-
 sub
 setclist
 {
@@ -695,6 +668,29 @@ check_command
     printyesno_val $name, $r_config->{$name};
 }
 
+sub
+check_env
+{
+    my ($name, $envvar, $val, $r_clist, $r_config) = @_;
+
+    $name = "_env_${envvar}";
+
+    printlabel $name, "env: $envvar";
+    # do not check cache
+
+    if ($ENV{$envvar} ne '') {
+      $val = $ENV{$envvar};
+    }
+    $val =~ s/^"//;
+    $val =~ s/"$//;
+    if ($val ne "") {
+      setlist $r_clist, $name;
+      $r_config->{$name} = $val;
+    }
+
+    printyesno_val $name, $r_config->{$name};
+}
+
 sub
 check_grep
 {
@@ -723,52 +719,6 @@ check_grep
     printyesno_val $name, $r_config->{$name};
 }
 
-sub
-check_ifoption
-{
-    my ($ifcount, $type, $name, $opt, $r_clist, $r_config) = @_;
-
-    printlabel $name, "$type ($ifcount): $opt";
-
-    loadoptions ();
-
-    my $trc = 0;
-
-    my $found = 'F';
-    if ($optionsloaded && defined ($optionshash{$opt})) {
-      $found = 'T';
-      $trc = lc $optionshash{$opt};
-      print LOGFH "##  found: $opt => $trc\n";
-      if ($trc eq 't') { $trc = 1; }
-      if ($trc eq 'enable') { $trc = 1; }
-      if ($trc eq 'f') { $trc = 0; }
-      if ($trc eq 'disable') { $trc = 0; }
-      if ($trc eq 'true') { $trc = 1; }
-      if ($trc eq 'false') { $trc = 0; }
-      if ($trc eq 'yes') { $trc = 1; }
-      if ($trc eq 'no') { $trc = 0; }
-    }
-
-    if (! $optionsloaded) {
-      $trc = 0;
-    } elsif ($found eq 'F') {
-      $trc = 0;
-    }
-
-    if ($type eq 'ifnotoption') {
-      $trc = $trc == 0 ? 1 : 0;
-    }
-
-    if (! $optionsloaded) {
-      printyesno_actual $name, "no options file";
-    } elsif ($found eq 'F') {
-      printyesno_actual $name, "option not found";
-    } else {
-      printyesno $name, $trc;
-    }
-    return $trc;
-}
-
 sub
 check_if
 {
@@ -878,26 +828,6 @@ check_set
     }
 }
 
-sub
-check_option
-{
-    my ($name, $onm, $def, $r_clist, $r_config) = @_;
-
-    printlabel $name, "option: $onm";
-
-    loadoptions ();
-    my $oval = $def;
-
-    if ($optionsloaded && defined ($optionshash{$onm})) {
-      $oval = $optionshash{$onm};
-      print LOGFH "##  found: $onm => $oval\n";
-    }
-
-    setlist $r_clist, $name;
-    $r_config->{$name} = $oval;
-    printyesno_actual $name, $r_config->{$name};
-}
-
 sub
 check_include_conflict
 {
@@ -1117,12 +1047,12 @@ check_lib
       $code = <<"_HERE_";
 CPP_EXTERNS_BEG
 #undef $rfunc
-typedef void (*_TEST_fun_)(void);
-char $rfunc(void);
-_TEST_fun_ f = (void *) $rfunc;
+typedef char (*_TEST_fun_)();
+char $rfunc();
+_TEST_fun_ f = $rfunc;
 CPP_EXTERNS_END
 int main () {
-if ((void *) f == (void *) $rfunc) { return 0; }
+if (f == $rfunc) { return 0; }
 return 1;
 }
 _HERE_
@@ -1130,11 +1060,11 @@ _HERE_
       $hinc = 'all';
       $code = <<"_HERE_";
 CPP_EXTERNS_BEG
-typedef void (*_TEST_fun_)(void);
-_TEST_fun_ f = (void *) $rfunc;
+typedef char (*_TEST_fun_)();
+_TEST_fun_ f = $rfunc;
 CPP_EXTERNS_END
 int main () {
-f(); if ((void *) f == (void *) $rfunc) { return 0; }
+f(); if (f == $rfunc) { return 0; }
 return 1;
 }
 _HERE_
@@ -1482,8 +1412,8 @@ create_output
     From: ${configfile}
     Using: mkconfig-${_MKCONFIG_VERSION} (perl) */
 
-#ifndef MKC_INC_${CONFHTAGUC}_H
-#define MKC_INC_${CONFHTAGUC}_H 1
+#ifndef INC_${CONFHTAGUC}_H
+#define INC_${CONFHTAGUC}_H 1
 
 _HERE_
 
@@ -1494,19 +1424,37 @@ _HERE_
     }
     my $tval = 0;
     if ($r_config->{$val} ne "0") {
-        $tval = 1;
+      $tval = 1;
     }
-    if ($val =~ m#^_setint_#o) {
+    if ($val =~ m#^_envquote_#o) {
+      ;
+    } elsif ($val =~ m#^_setint_#o) {
       $tnm = $val;
       $tnm =~ s/^_setint_//;
       print CCOFH "#define $tnm " . $r_config->{$val} . "\n";
     } elsif ($val =~ m#^(_setstr_|_opt_|_cmd_loc_)#o) {
+      my $isopt = 0;
+      if ($val =~ m#^_opt_#o) {
+        $isopt = 1;
+      }
       $tnm = $val;
       $tnm =~ s/^_setstr_//;
       $tnm =~ s/^_opt_//;
-      print CCOFH "#define $tnm \"" . $r_config->{$val} . "\"\n";
+      if (! $isopt || ($isopt && $r_config->{$val} != "")) {
+        print CCOFH "#define $tnm \"" . $r_config->{$val} . "\"\n";
+      }
     } elsif ($val =~ m#^(_hdr|_sys|_command)#o) {
       print CCOFH "#define $val $tval\n";
+    } elsif ($val =~ m#^(_env_)#o) {
+      my $envvar = $val;
+      $envvar =~ s/^_env_//;
+      my $qnm = "_envquote_${envvar}";
+      my $data = $r_config->{$val};
+      if (defined ($r_config->{$qnm}) && $r_config->{$qnm} eq '1') {
+        print CCOFH "#define $envvar \"$data\"\n";
+      } else {
+        print CCOFH "#define $envvar $data\n";
+      }
     } else {
       print CCOFH "#define $val " . $r_config->{$val} . "\n";
     }
@@ -1521,21 +1469,13 @@ _HERE_
 #  define void int
 # endif
 # if ! _key_void || ! _param_void_star
-   typedef char *_pvoid;
+   typedef char *pvoid;
 # else
-   typedef void *_pvoid;
+   typedef void *pvoid;
 # endif
 # if ! _key_const
 #  define const
 # endif
-
-# ifndef _
-#  if _proto_stdc
-#   define _(args) args
-#  else
-#   define _(args) ()
-#  endif
-# endif
 #endif /* MKC_STANDARD_DEFS */
 
 _HERE_
@@ -1544,7 +1484,7 @@ _HERE_
 
   print CCOFH <<"_HERE_";
 
-#endif /* MKC_INC_${CONFHTAGUC}_H */
+#endif /* INC_${CONFHTAGUC}_H */
 _HERE_
   close CCOFH;
 }
@@ -1566,7 +1506,7 @@ main_process
       open (MKCC, "<$CACHEFILE");
       while (my $line = <MKCC>) {
         chomp $line;
-        if ($line =~ m/^mkc_c_(.*)=\$?'?(.*)'?/o) {
+        if ($line =~ m/^mkc(.*)=\$?'?(.*)'?/o) {
           my $name = $1;
           my $val = $2;
           $config{$name} = $val;
@@ -1694,21 +1634,10 @@ main_process
             $CONFHTAGUC = uc $CONFHTAG;
             print LOGFH "config file: $CONFH\n";
             $inproc = 1;
-            $VARSFILE = "../../${MKC_FILES}/mkc_${CONFHTAG}_c.vars";
+            $VARSFILE = "../../${MKC_FILES}/mkc_${CONFHTAG}.vars";
             $clist{'vars'} = ();
             $clist{'vhash'} = {};
         }
-        elsif ($line =~ m#^\s*option\-file\s+([^\s]+)#o)
-        {
-            print "option-file: $1\n";
-            my $tfile = $1;
-            if ($tfile =~ m#^/#o) {
-              $OPTIONFILE = $tfile;
-            } else {
-              $OPTIONFILE = "../../$tfile";
-            }
-            print LOGFH "options file: $OPTIONFILE\n";
-        }
         elsif ($line =~ m#^\s*standard#o)
         {
             check_standard (\%clist, \%config);
@@ -1790,19 +1719,6 @@ main_process
         {
             check_grep ('', $1, \%clist, \%config);
         }
-        elsif ($line =~ m#^\s*(if(not)?option)\s+([^\s]+)#o)
-        {
-            my $type = $1;
-            my $opt = $3;
-            my $nm = "_${type}_${opt}";
-            ++$ifstmtcount;
-            my $rc = check_ifoption ($ifstmtcount, $type, $nm, $opt, \%clist, \%config);
-            $iflevels .= "+$ifstmtcount ";
-            unshift @doproclist, $doproc;
-            $doproc = $rc;
-            print LOGFH "## ifoption: doproclist: " . join (' ', @doproclist) . "\n";
-            print LOGFH "## ifoption: doproc: $doproc\n";
-        }
         elsif ($line =~ m#^\s*if\s+([^\s]+)\s+(.*)#o)
         {
             my $iflabel = $1;
@@ -1840,13 +1756,6 @@ main_process
             my $val = $4;
             check_set ($nm, $type, $val, \%clist, \%config);
         }
-        elsif ($line =~ m#^\s*option\s+([^\s]+)\s*(.*)#o)
-        {
-            my $nm = "_opt_$1";
-            my $onm = $1;
-            my $def = $2;
-            check_option ($nm, $onm, $def, \%clist, \%config);
-        }
         elsif ($line =~ m#^\s*npt\s+([^\s]*)\s*(.*)#o)
         {
             my $func = $1;
@@ -1967,6 +1876,20 @@ main_process
                 check_size ($nm, $typ, \%clist, \%config);
             }
         }
+        elsif ($line =~ m#^\s*env\s+(\w+)(\s+(quote))?(\s+(.*))?#o)
+        {
+            my $envvar = $1;
+            my $qnm = "_envquote_" . $envvar;
+            my $nm = "_env_" . $envvar;
+            my $val = '';
+            setclist \%clist, $qnm;
+            $config{$qnm} = '0';
+            if ($3 eq "quote") {
+              $config{$qnm} = '1';
+            }
+            $val = $5;
+            check_env ($nm, $envvar, $val, \%clist, \%config);
+        }
         else
         {
             print LOGFH "unknown command: $line\n";
@@ -1992,12 +1915,11 @@ sub
 usage
 {
   print STDOUT "Usage: $0 [-c <cache-file>] [-L <log-file>]\n";
-  print STDOUT "       [-o <option-file>] [-C] <config-file>\n";
+  print STDOUT "       [-C] <config-file>\n";
   print STDOUT "  -C : clear cache-file\n";
   print STDOUT "defaults:\n";
   print STDOUT "  <cache-file> : mkconfig.cache\n";
   print STDOUT "  <log-file>   : mkconfig.log\n";
-  print STDOUT "  <option-file>: options.dat\n";
 }
 
 # main
@@ -2022,12 +1944,6 @@ while ($#ARGV > 0)
       $LOG = $ARGV[0];
       shift @ARGV;
   }
-  if ($ARGV[0] eq "-o")
-  {
-      shift @ARGV;
-      $OPTIONFILE = $ARGV[0];
-      shift @ARGV;
-  }
 }
 
 my $configfile = $ARGV[0];
