@@ -357,12 +357,23 @@ check_addincpath () {
   fi
 }
 
+helper_pkg_path () {
+  for p in $HOME/local/lib /usr/local/lib \
+      /opt/local/lib /opt/homebrew/lib /usr/pkg/lib /usr/local/lib/hpux64; do
+    if [ -d $td ]; then
+      doappend PKG_CONFIG_PATH $p
+    fi
+  done
+}
+
+
 check_pkg_cflags () {
   name=$1
   pkgname=$2
   pkgpath=$3
 
   OPKG_CONFIG_PATH=$PKG_CONFIG_PATH
+  helper_pkg_path
   if [ "$pkgpath" != "" ]; then
     if [ "$PKG_CONFIG_PATH" != "" ]; then
       doappend PKG_CONFIG_PATH :
@@ -390,6 +401,7 @@ check_pkg_include () {
   pkgpath=$3
 
   OPKG_CONFIG_PATH=$PKG_CONFIG_PATH
+  helper_pkg_path
   if [ "$pkgpath" != "" ]; then
     if [ "$PKG_CONFIG_PATH" != "" ]; then
       doappend PKG_CONFIG_PATH :
@@ -417,6 +429,7 @@ check_pkg_libs () {
   pkgpath=$3
 
   OPKG_CONFIG_PATH=$PKG_CONFIG_PATH
+  helper_pkg_path
   if [ "$pkgpath" != "" ]; then
     if [ "$PKG_CONFIG_PATH" != "" ]; then
       doappend PKG_CONFIG_PATH :
@@ -520,7 +533,7 @@ check_ldflags () {
         doappend ldflags_system " -L/usr/local/lib"
         ;;
       NetBSD)
-        doappend ldflags_system " -L/usr/pkg/lib"
+        doappend ldflags_system " -Wl,-R/usr/pkg/lib -L/usr/pkg/lib"
         ;;
       HP-UX)
         # check for libintl in other places...
@@ -880,7 +893,7 @@ check_sharerunpathflag () {
         LDFLAGS_RUNPATH="-rpath "
         ;;
       SCO_SV)
-        LDFLAGS_RUNPATH="-R "
+        LDFLAGS_RUNPATH="-Wl,-R"
         ;;
       SunOS)
         LDFLAGS_RUNPATH="-R"
@@ -892,13 +905,17 @@ check_sharerunpathflag () {
         LDFLAGS_RUNPATH=""
         ;;
     esac
-    if [ "$_MKCONFIG_USING_GCC" = Y -o "$_MKCONFIG_USING_CLANG" = Y ]; then
-      # the trailing space will be converted to ' -Wl,' and
-      # the library runpath will be appended by mkcl.sh
-      LDFLAGS_RUNPATH=`echo "$LDFLAGS_RUNPATH" |
-          sed -e 's/^-/-Wl,-/' -e 's/^\+/-Wl,+/' -e 's/  */ -Wl,/g'`
+    if [ "$_MKCONFIG_USING_GNU_LD" != Y -a "$_MKCONFIG_USING_CLANG" = Y ]; then
+      LDFLAGS_RUNPATH="-rpath "
     fi
+#    if [ "$_MKCONFIG_USING_GCC" = Y -o "$_MKCONFIG_USING_CLANG" = Y ]; then
+#      # the trailing space will be converted to ' -Wl,' and
+#      # the library runpath will be appended by mkcl.sh
+#      LDFLAGS_RUNPATH=`echo "$LDFLAGS_RUNPATH" |
+#          sed -e 's/^-/-Wl,-/' -e 's/^\+/-Wl,+/' -e 's/  */ -Wl,/g'`
+#    fi
   fi
+set +x
 
   printyesno_val LDFLAGS_RUNPATH "$LDFLAGS_RUNPATH"
   setdata LDFLAGS_RUNPATH "$LDFLAGS_RUNPATH"
@@ -923,41 +940,6 @@ check_addconfig () {
   fi
 }
 
-check_findconfig () {
-  name=$1
-  cfile=$2
-  printlabel FINDCONFIG "Search for: ${cfile}"
-  sp=
-  incchk=
-  pp=`puts $PATH | sed 's/:/ /g'`
-  for p in $pp $HOME/local/lib /usr/local/lib \
-      /opt/local/lib /opt/homebrew/lib /usr/pkg/lib /usr/local/lib/hpux64; do
-    td=$p
-    case $p in
-      */bin)
-        td=`puts $p | sed 's,/bin$,/lib,'`
-        ;;
-    esac
-    if [ -d $td ]; then
-      if [ -f "$td/$cfile.sh" ]; then
-        puts "found: ${td}" >&9
-        sp=$td
-        break
-      fi
-    fi
-  done
-
-  if [ z$sp != z ]; then
-    printyesno_val $name yes
-    setdata config_${cfile} Y
-    setdata config_path_${cfile} $sp/$cfile
-    . $sp/$cfile.sh ; # load the environment variables
-  else
-    printyesno_val $name no
-    setdata config_${cfile} N
-  fi
-}
-
 check_standard_cc () {
   check_cc
   check_using_gcc
