@@ -15,7 +15,6 @@
 #    5 - temporary for c-main.sh    (c-main.sh)
 #
 
-_MKCONFIG_PREFIX=env
 _MKCONFIG_HASEMPTY=T
 _MKCONFIG_EXPORT=T
 
@@ -61,7 +60,7 @@ check_source () {
     val=$fn
   fi
   printyesno $name $trc
-  setdata ${_MKCONFIG_PREFIX} ${name} $val
+  setdata ${name} $val
 }
 
 output_item () {
@@ -93,11 +92,9 @@ check_test_multword () {
   name=$1
 
   printlabel $name "test: multiword"
-  checkcache_val ${_MKCONFIG_PREFIX} $name
-  if [ $? -eq 0 ]; then return; fi
   val="word1 word2"
   printyesno_val $name "$val"
-  setdata ${_MKCONFIG_PREFIX} $name "$val"
+  setdata $name "$val"
 }
 
 new_output_file () {
@@ -161,15 +158,21 @@ check_pkg_exists () {
 
 test_cflag () {
   flag=$1
+  quoted=$2
 
   puts "#include <stdio.h>
-int main () { return 0; }" > t.c
+int main (int argc, char *argv []) { return 0; }" > t.c
   puts "# test ${flag}" >&9
   # need to set w/all cflags; gcc doesn't always error out otherwise
   TMPF=t$$.txt
   setcflags
-  ${CC} ${CFLAGS} ${flag} t.c > $TMPF 2>&1
-  rc=$?
+  if [ "$quoted" != "" ]; then
+    ${CC} ${CFLAGS} "${flag}" t.c > $TMPF 2>&1
+    rc=$?
+  else
+    ${CC} ${CFLAGS} ${flag} t.c > $TMPF 2>&1
+    rc=$?
+  fi
   if [ $rc -ne 0 ]; then
     flag=0
   fi
@@ -178,23 +181,43 @@ int main () { return 0; }" > t.c
   if [ $rc -eq 0 ]; then
     flag=0
   fi
+  grep -i "error.*${flag}" $TMPF > /dev/null 2>&1
+  rc=$?
+  if [ $rc -eq 0 ]; then
+    flag=0
+  fi
+  # AIX
+  grep -i "Option.*incorrectly specified" $TMPF > /dev/null 2>&1
+  rc=$?
+  if [ $rc -eq 0 ]; then
+    flag=0
+  fi
+
   cat $TMPF >&9
   rm -f $TMPF > /dev/null 2>&1
 }
 
 test_ldflags () {
   flag=$1
+  quoted=$2
 
   setcflags
   setldflags
   setlibs
   puts "#include <stdio.h>
-int main () { return 0; }" > t.c
+int main (int argc, char *argv []) {
+  return 0;
+}" > t.c
   puts "# test ${flag}" >&9
   # need to set w/all cflags/ldflags; gcc doesn't always error out otherwise
   TMPF=t$$.txt
-  ${CC} ${CFLAGS} ${LDFLAGS} ${flag} -o t t.c > $TMPF 2>&1
-  rc=$?
+  if [ "$quoted" != "" ]; then
+    ${CC} ${CFLAGS} ${LDFLAGS} "${flag}" -o t t.c > $TMPF 2>&1
+    rc=$?
+  else
+    ${CC} ${CFLAGS} ${LDFLAGS} ${flag} -o t t.c > $TMPF 2>&1
+    rc=$?
+  fi
   if [ $rc -ne 0 ]; then
     flag=0
   fi
@@ -203,6 +226,40 @@ int main () { return 0; }" > t.c
   if [ $rc -eq 0 ]; then
     flag=0
   fi
+  grep -i "error.*${flag}" $TMPF > /dev/null 2>&1
+  rc=$?
+  if [ $rc -eq 0 ]; then
+    flag=0
+  fi
   cat $TMPF >&9
   rm -f $TMPF > /dev/null 2>&1
 }
+
+test_incpath () {
+  flag=$1
+
+  if [ -d "$flag" ]; then
+    test_cflag "-I$flag" quoted
+  else
+    if [ -d "$origcwd/$flag" ]; then
+      test_cflag "-I$origcwd/$flag" quoted
+    else
+      flag=0
+    fi
+  fi
+}
+
+test_ldsrchpath () {
+  flag=$1
+
+  if [ -d "$flag" ]; then
+    test_ldflags "-L$flag" quoted
+  else
+    if [ -d "$origcwd/$flag" ]; then
+      test_cflag "-L$origcwd/$flag" quoted
+    else
+      flag=0
+    fi
+  fi
+}
+
